#include <../base.hpp>

#define ST011_CPP
namespace bSNES_v059 {

ST011 st011;

void ST011::init() {
}

void ST011::enable() {
}

void ST011::power() {
}

void ST011::reset() {
}

};
